# g85 README

`g85` is a Python module for reading and writing to the G85 XML wafer map format.


### Links
- [Source repository](https://mpxd.net/code/jan/g85)
- [PyPI](https://pypi.org/project/g85)


## Installation

Requirements:
* python >= 3.7 (written and tested with 3.9)
* numpy


Install with pip:
```bash
pip3 install g85
```

Alternatively, install from git
```bash
pip3 install git+https://mpxd.net/code/jan/g85.git@release
```

## Examples
